@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-cookie-manager.h 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_COOKIE_MANAGER_H
@@ -50,6 +50,7 @@ typedef struct
 	glong real_expires;
         guint is_secure : 1;
         guint is_session : 1;
+        guint is_http_only : 1;
 } EphyCookie;
 
 struct _EphyCookieManagerIface
