@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-embed-shell.h 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_EMBED_SHELL_H
@@ -23,8 +23,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gtk/gtkpagesetup.h>
-#include <gtk/gtkprintsettings.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
