@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphySingle.cpp 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -348,6 +348,12 @@ mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 		info->real_expires = expiry;
 	}
 
+#ifdef HAVE_GECKO_1_9
+        PRBool isHttpOnly = PR_FALSE;
+        cookie2->GetIsHttpOnly (&isHttpOnly);
+        info->is_http_only = isHttpOnly != PR_FALSE;
+#endif
+
 	return info;
 }
 
