@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-chooser.c 7502 2007-09-28 04:59:47Z diegoe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -28,10 +28,9 @@
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 #include "ephy-stock-icons.h"
+#include "ephy-string.h"
 
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #define EPHY_FILE_CHOOSER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_FILE_CHOOSER, EphyFileChooserPrivate))
@@ -112,10 +111,11 @@ file_chooser_response_cb (GtkWidget *widget,
 			char *dir, *filename;
 		    
 			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+                        if (filename == NULL) return;
 
 			dir = g_path_get_dirname (filename);
-
-			eel_gconf_set_path (dialog->priv->persist_key, dir);
+                        if (dir != NULL)
+        			eel_gconf_set_path (dialog->priv->persist_key, dir);
 
 			g_free (dir);
 			g_free (filename);
@@ -175,12 +175,14 @@ ephy_file_chooser_set_persist_key (EphyFileChooser *dialog, const char *key)
 	dir = eel_gconf_get_string (key);
 	if (dir != NULL)
 	{
+		/* FIXME: Maybe we will find a better way to do this when the
+		 * gio-filechooser will be in GTK+ */
 		converted = g_filename_from_utf8
 			(dir, -1, NULL, NULL, NULL);
 
 		if (converted != NULL)
 		{
-			expanded = gnome_vfs_expand_initial_tilde (converted);
+			expanded = ephy_string_expand_initial_tilde (converted);
 
 			gtk_file_chooser_set_current_folder
 				(GTK_FILE_CHOOSER (dialog), expanded);
