@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-topic-action.c 7858 2008-01-13 20:42:01Z cosimoc $
+ *  $Id$
  */
 
 #include "config.h"
@@ -34,18 +34,7 @@
 #include "ephy-dnd.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 static const GtkTargetEntry dest_drag_types[] = {
@@ -72,7 +61,7 @@ enum
 	PROP_MANAGER
 };
 
-static GObjectClass *parent_class;
+G_DEFINE_TYPE (EphyTopicAction, ephy_topic_action, GTK_TYPE_ACTION)
 
 static void
 drag_data_received_cb (GtkWidget *widget,
@@ -130,7 +119,7 @@ create_tool_item (GtkAction *action)
 	GtkWidget *hbox;
 	GtkWidget *label;
 
-	item = GTK_ACTION_CLASS (parent_class)->create_tool_item (action);
+	item = GTK_ACTION_CLASS (ephy_topic_action_parent_class)->create_tool_item (action);
 
 	button = gtk_toggle_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
@@ -138,7 +127,8 @@ create_tool_item (GtkAction *action)
 	gtk_widget_show (button);
 	gtk_container_add (GTK_CONTAINER (item), button);
 	g_object_set_data (G_OBJECT (item), "button", button);
-	g_object_set_data (G_OBJECT (button), "gtk-action", action);
+	gtk_activatable_set_related_action (GTK_ACTIVATABLE (button),
+					    action);
 
 	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
 	gtk_widget_show (arrow);
@@ -387,8 +377,7 @@ button_enter_cb (GtkWidget *button,
 	    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (active_button)))
 	{
 		EphyTopicAction *active_action;
-		active_action = g_object_get_data (G_OBJECT (active_button),
-						   "gtk-action");
+		active_action = gtk_widget_get_action (GTK_WIDGET (active_button));
 
 		erase_popup (active_action);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (active_button), FALSE);
@@ -402,7 +391,7 @@ static void
 connect_proxy (GtkAction *action,
 	       GtkWidget *proxy)
 {
-	GTK_ACTION_CLASS (parent_class)->connect_proxy (action, proxy);
+	GTK_ACTION_CLASS (ephy_topic_action_parent_class)->connect_proxy (action, proxy);
     
 	ephy_topic_action_sync_label (action, NULL, proxy);
 	g_signal_connect_object (action, "notify::label",
@@ -561,13 +550,7 @@ ephy_topic_action_get_property (GObject *object,
 static void
 ephy_topic_action_init (EphyTopicAction *action)
 {
-	EphyTopicActionPrivate *priv;
-
-	priv = action->priv = EPHY_TOPIC_ACTION_GET_PRIVATE (action);
-	
-	priv->merge_id = 0;
-	priv->node = NULL;
-	priv->manager = NULL;
+	action->priv = EPHY_TOPIC_ACTION_GET_PRIVATE (action);
 }
 
 static void
@@ -576,8 +559,6 @@ ephy_topic_action_class_init (EphyTopicActionClass *class)
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
 
-	parent_class = g_type_class_peek_parent (class);
-
 	action_class->toolbar_item_type = GTK_TYPE_TOOL_ITEM;
 	action_class->create_tool_item = create_tool_item;
 	action_class->connect_proxy = connect_proxy;
@@ -605,34 +586,6 @@ ephy_topic_action_class_init (EphyTopicActionClass *class)
 	g_type_class_add_private (object_class, sizeof(EphyTopicActionPrivate));
 }
 
-GType
-ephy_topic_action_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo type_info =
-		{
-			sizeof (EphyTopicActionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) ephy_topic_action_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (EphyTopicAction),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_topic_action_init,
-		};
-
-		type = g_type_register_static (GTK_TYPE_ACTION,
-					       "EphyTopicAction",
-					       &type_info, 0);
-	}
-
-	return type;
-}
-
 GtkAction *
 ephy_topic_action_new (EphyNode *node,
 		       GtkUIManager *manager,
