@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  Copyright © 2003 Marco Pesenti Gritti
  *  Copyright © 2003, 2004 Christian Persch
@@ -18,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-extensions-manager.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -28,6 +29,8 @@
 #include "ephy-loader.h"
 #include "ephy-shlib-loader.h"
 
+#include "ephy-embed-container.h"
+
 #include "ephy-node-db.h"
 #include "ephy-shell.h"
 #include "eel-gconf-extensions.h"
@@ -46,11 +49,9 @@
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
 
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-
 #include <gconf/gconf-client.h>
 
+#include <gio/gio.h>
 #include <gmodule.h>
 #include <dirent.h>
 #include <string.h>
@@ -128,50 +129,13 @@ enum
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-static GObjectClass *parent_class = NULL;
-
 static void ephy_extensions_manager_class_init	(EphyExtensionsManagerClass *klass);
 static void ephy_extensions_manager_iface_init	(EphyExtensionIface *iface);
 static void ephy_extensions_manager_init	(EphyExtensionsManager *manager);
 
-GType
-ephy_extensions_manager_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyExtensionsManagerClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) ephy_extensions_manager_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (EphyExtensionsManager),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_extensions_manager_init
-		};
-
-		const GInterfaceInfo extension_info =
-		{
-			(GInterfaceInitFunc) ephy_extensions_manager_iface_init,
-			NULL,
-			NULL
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "EphyExtensionsManager",
-					       &our_info, 0);
-
-		g_type_add_interface_static (type,
-					     EPHY_TYPE_EXTENSION,
-					     &extension_info);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE_WITH_CODE (EphyExtensionsManager, ephy_extensions_manager, G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (EPHY_TYPE_EXTENSION,
+						ephy_extensions_manager_iface_init))
 
 /**
  * ephy_extensions_manager_load:
@@ -676,11 +640,12 @@ attach_window (EphyWindow *window,
 
 	ephy_extension_attach_window (extension, window);
 
-	tabs = ephy_window_get_tabs (window);
+	tabs = ephy_embed_container_get_children 
+          (EPHY_EMBED_CONTAINER (window));
 	for (l = tabs; l; l = l->next)
 	{
 		ephy_extension_attach_tab (extension, window,
-					   EPHY_TAB (l->data));
+					   EPHY_EMBED (l->data));
 	}
 	g_list_free (tabs);
 }
@@ -739,11 +704,12 @@ detach_window (EphyWindow *window,
 {
 	GList *tabs, *l;
 
-	tabs = ephy_window_get_tabs (window);
+	tabs = ephy_embed_container_get_children 
+          (EPHY_EMBED_CONTAINER (window));
 	for (l = tabs; l; l = l->next)
 	{
 		ephy_extension_detach_tab (extension, window,
-					   EPHY_TAB (l->data));
+					   EPHY_EMBED (l->data));
 	}
 	g_list_free (tabs);
 
@@ -993,35 +959,35 @@ schedule_load_from_monitor (EphyExtensionsManager *manager,
 }
 
 static void
-dir_changed_cb (GnomeVFSMonitorHandle *handle,
-		const char *monitor_uri,
-		const char *info_uri,
-		GnomeVFSMonitorEventType event_type,
+dir_changed_cb (GFileMonitor *monitor,
+		GFile *child,
+		GFile *other_child,
+		GFileMonitorEvent event_type,
 		EphyExtensionsManager *manager)
 {
 	char *path;
+	
+	path = g_file_get_path (child);
 
 	/*
 	 * We only deal with XML and INI files:
 	 * Add them to the manager when created, remove them when deleted.
 	 */
-	if (format_from_path (info_uri) == FORMAT_UNKNOWN) return;
-
-	path = gnome_vfs_get_local_path_from_uri (info_uri);
+	if (format_from_path (path) == FORMAT_UNKNOWN) return;
 
 	switch (event_type)
 	{
-		case GNOME_VFS_MONITOR_EVENT_CREATED:
-		case GNOME_VFS_MONITOR_EVENT_CHANGED:
+		case G_FILE_MONITOR_EVENT_CREATED:
+		case G_FILE_MONITOR_EVENT_CHANGED:
 			schedule_load_from_monitor (manager, path);
 			break;
-		case GNOME_VFS_MONITOR_EVENT_DELETED:
+		case G_FILE_MONITOR_EVENT_DELETED:
 			ephy_extensions_manager_unload_file (manager, path);
 			break;
 		default:
 			break;
 	}
-
+	
 	g_free (path);
 }
 
@@ -1032,9 +998,8 @@ ephy_extensions_manager_load_dir (EphyExtensionsManager *manager,
 	DIR *d;
 	struct dirent *e;
 	char *file_path;
-	char *file_uri;
-	GnomeVFSMonitorHandle *monitor;
-	GnomeVFSResult res;
+	GFile *directory;
+	GFileMonitor *monitor;
 
 	LOG ("Scanning directory '%s'", path);
 
@@ -1056,16 +1021,14 @@ ephy_extensions_manager_load_dir (EphyExtensionsManager *manager,
 	}
 	closedir (d);
 
-	file_uri = gnome_vfs_get_uri_from_local_path (path);
-	res = gnome_vfs_monitor_add (&monitor,
-				     path,
-				     GNOME_VFS_MONITOR_DIRECTORY,
-				     (GnomeVFSMonitorCallback) dir_changed_cb,
-				     manager);
-	g_free (file_uri);
+	directory = g_file_new_for_path (path);
+	monitor = g_file_monitor_directory (directory, 0, NULL, NULL);
 
-	if (res == GNOME_VFS_OK)
+	if (monitor != NULL)
 	{
+		g_signal_connect (monitor, "changed",
+				  G_CALLBACK (dir_changed_cb),
+				  manager);
 		manager->priv->dir_monitors = g_list_prepend
 			(manager->priv->dir_monitors, monitor);
 	}
@@ -1160,7 +1123,7 @@ ephy_extensions_manager_dispose (GObject *object)
 
 	if (priv->dir_monitors != NULL)
 	{
-		g_list_foreach (priv->dir_monitors, (GFunc) gnome_vfs_monitor_cancel, NULL);
+		g_list_foreach (priv->dir_monitors, (GFunc) g_file_monitor_cancel, NULL);
 		g_list_free (priv->dir_monitors);
 		priv->dir_monitors = NULL;
 	}
@@ -1193,7 +1156,7 @@ ephy_extensions_manager_dispose (GObject *object)
 		priv->windows = NULL;
 	}
 
-	parent_class->dispose (object);
+	G_OBJECT_CLASS (ephy_extensions_manager_parent_class)->dispose (object);
 }
 
 static void
@@ -1231,11 +1194,11 @@ impl_detach_window (EphyExtension *extension,
 	g_object_ref (window);
 
 	/* Detach tabs (uses impl_detach_tab) */
-	tabs = ephy_window_get_tabs (window);
+	tabs = ephy_embed_container_get_children (EPHY_EMBED_CONTAINER (window));
 	for (l = tabs; l; l = l->next)
 	{
 		ephy_extension_detach_tab (extension, window,
-					   EPHY_TAB (l->data));
+					   EPHY_EMBED (l->data));
 	}
 	g_list_free (tabs);
 
@@ -1249,40 +1212,40 @@ impl_detach_window (EphyExtension *extension,
 static void
 impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
 	EphyExtensionsManager *manager = EPHY_EXTENSIONS_MANAGER (extension);
 	GList *l;
 
-	LOG ("Attach window %p tab %p", window, tab);
+	LOG ("Attach window %p embed %p", window, embed);
 
 	for (l = manager->priv->extensions; l; l = l->next)
 	{
 		ephy_extension_attach_tab (EPHY_EXTENSION (l->data),
-					   window, tab);
+					   window, embed);
 	}
 }
 
 static void
 impl_detach_tab (EphyExtension *extension,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
 	EphyExtensionsManager *manager = EPHY_EXTENSIONS_MANAGER (extension);
 	GList *l;
 
-	LOG ("Detach window %p tab %p", window, tab);
+	LOG ("Detach window %p embed %p", window, embed);
 
 	g_object_ref (window);
-	g_object_ref (tab);
+	g_object_ref (embed);
 
 	for (l = manager->priv->extensions; l; l = l->next)
 	{
 		ephy_extension_detach_tab (EPHY_EXTENSION (l->data),
-					   window, tab);
+					   window, embed);
 	}
 
-	g_object_unref (tab);
+	g_object_unref (embed);
 	g_object_unref (window);
 }
 
@@ -1300,8 +1263,6 @@ ephy_extensions_manager_class_init (EphyExtensionsManagerClass *class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
-	parent_class = (GObjectClass *) g_type_class_peek_parent (class);
-
 	object_class->dispose = ephy_extensions_manager_dispose;
 
 	signals[CHANGED] =
