@@ -17,13 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.h 7127 2007-07-10 11:56:30Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_STATUSBAR_H
 #define EPHY_STATUSBAR_H
 
-#include <gtk/gtkstatusbar.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
